 /* demo 3208-spi lib fnctns w ds1620 common pins.c       MPC3208 ADC and DS1620 interface using spiasm library

***** Note This version uses common IO and Clock pins for both devices ****    
***** NOTE This version uses functions in the "libspiasm" library  *****
Functions used in this program are in libspiasm.

  Function version with main() as demo of using 2 SPI devices
  Uses pasm in xspiasm.spin, modified from SPI_Asm.spin propeller tool library object.
   T Montemarano  (MIT License)
   
   The SPI devices called in main() are a MPC3208 ADC and DS1620 digital thermometer.    
    Used wiring from Programming & Customizing the Multicore Propeller Microcontroller
        page 158, but using MPC3208 ADC instead of MPC3204.  (16 pin vs 14 pin device). 
        Note there are different device pin definitions.
      
 */
 
 #include "simpletools.h"                      // Library includes
 #include "spiasm.h"
   
 /* ******************************************************
    Uses MPC3208 ADC as SPI device
 
        MPC3208 pin                  Prop pin 

          CS                <-    Prop P2  low starts transfer, high terminates
          DATA in/out       <->   Prop P1  Prop out (MFIRST), Prop in (MPOST) 
          Clock             <-    Prop P0  rise then fall  State = 0   
*/
 
 // #define cstate3208 0        // Put in start function 0 = start clock low, 1 = start clock high
 #define clockd_ns3208 1000   // Actual delay in nanoseconds (1000ns = 1 usec), not less than 300ns
                             // ClockDelay, actual clock delay = 300ns + (cdelay-1) * 50ns
                             // e.g. cdelay of 15 gives actual clock delay = 1 usec
                             // cdelay = ((clockd_ns) - 250ns)) / 50ns
                             // e.g. for 2 usec (i.e. 2000 ns): cdelay = 35
 //  ** Propeller pins 

 #define IOPIN3208 1         // both devices share this pin
 #define CLKPIN3208 0        // both devices share this pin
 #define CS3208 2

 #define VREF 5       // for 5 volt Vdd and Vref  For lower Vdd voltage may have to set clock_ns slower
 #define MAXCHAN 5    // max channel number 0 to 7 (ch 0 & 1 = pots, 2 = 3.3v buss, 3 = Vss)

/* ******************************************************
   libspipasm DS1620.c  uses DS1620 as SPI device

    DS1620 data in/out     <->   Prop P4 with 330 ohm resistor, LSB first LPRE
    Clock                        <- Prop P5  fall then rise  State = 1
    Reset                       <- Prop P6  high starts transfer, low terminates
    After configuration data sent to device pause 10ms.
    Temperature conversion takes 1 sec
*/
#define cstate1620 1          // Put in start function 0 = start clock low, 1 = start clock high
#define clockd_ns1620 1000      // Actual delay in nanoseconds (1000ns = 1 usec), not less than 300ns
                                         // ClockDelay, actual clock delay = 300ns + (cdelay-1) * 50ns
                                         // e.g. cdelay of 15 gives actual clock delay = 1 usec
                                         // cdelay = ((clockd_ns) - 250ns)) / 50ns
                                         // e.g. for 2 usec (i.e. 2000 ns): cdelay = 35
//  ** Propeller pins 
#define IOPIN1620 1       // both devices share this pin
#define CLKPIN1620 0      // both devices share this pin
#define RESET1620 6

// **** Function Prototypes -- shouldn't need since these are in spiasm.h

//void start_3208se(int);     // int is clockd_ns3208
//int get_3208se(int,int,int,int);  // IO, CLK, CS, chnum - function prototype for single ended 3208 read

//void start_1620(int);             // clockd_ns1620 - function prototype for DS1620 start 
//void init_1620(int, int, int);    // IOPIN16, CLKPIN16, RESET16 - initialize and configure DS1620
//int get_1620(int, int, int);      //   IO, CLK, RESET -  DS1620 read temperature

spia_t *spia_1;   // both devices share same SPI buss & cog

   
int main()                              // Main function
{ 
  int i;
  int adcraw; 
  int voltsin; 
  int degC;
  int degF;
  float fvoltsin;
  float fdegC;
  float fdegF;

// *** start and configure SPI devices         
  spia_1 = start_1620(clockd_ns1620, cstate1620);  // only use start for DS1620, its cstate is critical, 3208's is not

  init_1620(spia_1, IOPIN1620, CLKPIN1620, RESET1620);    // add additional inits for multiple 1620s with their pin nums

  while(1)  // bb             primary loop
  {
    for(i = 0; i <= MAXCHAN; i++)   // aa     loop for 3208 data reads
    {
     int adcraw = get_3208se(spia_1, IOPIN3208, CLKPIN3208, CS3208, i);     // read channel i

// *** 3208 data handling & printout 
     voltsin = (adcraw * VREF * 1000) / 4095;
     fvoltsin = voltsin;
     print("Channel %d: raw = %d,  %.3f volts\n", i, adcraw, (fvoltsin/1000)); 
     pause(10);
    }           // end aa
    print("\n");

// *** DS1620 data
    degC = get_1620(spia_1, IOPIN1620, CLKPIN1620, RESET1620);                                                  // Read DS1620 
    if(degC & 0b100000000) degC = degC | 0xFFFFFF00; // degC <0, convert to 32bit signed int
    degC *= 5;                            // data is in 1/2 degree increments, make degC = 10 x
    degF = degC * 9 / 5 + 320;
    fdegC = degC;
    fdegF = degF;
    print(" %.1f deg C   ", fdegC/10);
    print(" %.1f deg F\n", fdegF/10);
    pause(800);
  }            // end bb      end primary loop
}              // end main

// *** Functions are defined in libspiasm ***
