 /* demo 3208-spi lib functions.c       MPC3208 ADC interface using spiasm library

***** NOTE This version uses functions in the "libspiasm" library  *****
Functions in this file are commented out.

  Function version with main() as demo of using MCP3208 SPI device
  Uses pasm in xspiasm.spin, modified from SPI_Asm.spin propeller tool library object.
   T Montemarano  (MIT License)
   
   The SPI device called in main() is an MPC3208 ADC.    
    Used wiring from Programming & Customizing the Multicore Propeller Microcontroller
        page 158, but using MPC3208 ADC instead of MPC3204.  (16 pin vs 14 pin device). 
        Note there are different device pin definitions.
        
 */
 
 #include "simpletools.h"                      // Library includes
 #include "spiasm.h"
   
 /* ******************************************************
    Uses MPC3208 ADC as SPI device
 
        MPC3208 pin                  Prop pin 

          CS                <-    Prop P2  low starts transfer, high terminates
          DATA in/out       <->   Prop P1  Prop out (MFIRST), Prop in (MPOST) 
          Clock             <-    Prop P0  rise then fall  State = 0   
*/
 
 #define cstate3208 0        // Put in start function 0 = start clock low, 1 = start clock high
 #define clockd_ns3208 1000   // Actual delay in nanoseconds (1000ns = 1 usec), not less than 300ns
                             // ClockDelay, actual clock delay = 300ns + (cdelay-1) * 50ns
                             // e.g. cdelay of 15 gives actual clock delay = 1 usec
                             // cdelay = ((clockd_ns) - 250ns)) / 50ns
                             // e.g. for 2 usec (i.e. 2000 ns): cdelay = 35
 //  ** Propeller pins 
 #define CS3208 2
 #define IOPIN3208 1
 #define CLKPIN3208 0

 #define VREF 5       // for 5 volt Vdd and Vref  For lower Vdd voltage may have to set clock_ns slower
 #define MAXCHAN 5    // max channel number 0 to 7 (ch 0 & 1 = pots, 2 = 3.3v buss, 3 = Vss)

// **** Function Prototypes -- don't need since these are in spiasm.h

//void start_3208se(int);     // int is clockd_ns3208
//int get_3208se(int,int,int,int);  // IO, CLK, CS, chnum - function prototype for single ended 3208 read

spia_t *spia_1; // for opening additional SPI cogs add *spia_2, etc. Note multiple SPI devices can share same cog.
   
int main()                              // Main function
{ 
  int i;
  int adcraw; 
  int voltsin; 
  float fvoltsin;

// *** start and configure SPI devices         
  spia_1 = start_3208se(clockd_ns3208, cstate3208);

  while(1)  // bb             primary loop
  {
    for(i = 0; i <= MAXCHAN; i++)   // aa     loop for 3208 data reads
    {
     int adcraw = get_3208se(spia_1, IOPIN3208, CLKPIN3208, CS3208, i);     // read channel i

// *** 3208 data handling & printout 
     voltsin = (adcraw * VREF * 1000) / 4095;
     fvoltsin = voltsin;
     print("Channel %d: raw = %d,  %.3f volts\n", i, adcraw, (fvoltsin/1000)); 
     pause(10);
    }           // end aa
    print("\n");
    pause(800);
  }            // end bb      end primary loop
}              // end main

