 /* demo ds1620-spi lib functions.c       DS1620 interface using spiasm library

***** NOTE This version uses functions in the "libspiasm" library  *****

  Function version with main() as demo of using 1 SPI device
  Uses pasm in xspiasm.spin, modified from SPI_Asm.spin propeller tool library object.
   T Montemarano  (MIT License)
   
   The SPI device called in main() is a DS1620 digital thermometer.    
    Used wiring from Programming & Customizing the Multicore Propeller Microcontroller
        page 158, but using MPC3208 ADC instead of MPC3204.  (16 pin vs 14 pin device). 
        Note there are different device pin definitions.
        
 */
 
 #include "simpletools.h"                      // Library includes
 #include "spiasm.h"
   
/* ******************************************************
   libspipasm DS1620.c  uses DS1620 as SPI device

    DS1620 data in/out     <->   Prop P4 with 330 ohm resistor, LSB first LPRE
    Clock                        <- Prop P5  fall then rise  State = 1
    Reset                       <- Prop P6  high starts transfer, low terminates
    After configuration data sent to device pause 10ms.
    Temperature conversion takes 1 sec
*/
#define cstate1620 1          // Put in start function 0 = start clock low, 1 = start clock high
#define clockd_ns1620 1000      // Actual delay in nanoseconds (1000ns = 1 usec), not less than 300ns
                                         // ClockDelay, actual clock delay = 300ns + (cdelay-1) * 50ns
                                         // e.g. cdelay of 15 gives actual clock delay = 1 usec
                                         // cdelay = ((clockd_ns) - 250ns)) / 50ns
                                         // e.g. for 2 usec (i.e. 2000 ns): cdelay = 35
//  ** Propeller pins 
#define IOPIN1620 4
#define CLKPIN1620 5
#define RESET1620 6

// **** Function Prototypes -- shouldn't need since these are in spiasm.h

//void start_1620(int);             // clockd_ns1620 - function prototype for DS1620 start 
//void init_1620(int, int, int);    // IOPIN16, CLKPIN16, RESET16 - initialize and configure DS1620
//int get_1620(int, int, int);      //   IO, CLK, RESET -  DS1620 read temperature


spia_t *spia_1;     // for opening additional SPI cogs add *spia_2, etc. Note multiple SPI devices can share same cog.
   
int main()                              // Main function
{ 
  int degC;
  int degF;
  float fdegC;
  float fdegF;

// *** start and configure SPI devices         
  spia_1 = start_1620(clockd_ns1620, cstate1620);
  init_1620(spia_1, IOPIN1620, CLKPIN1620, RESET1620);    // add additional inits for multiple 1620s with their pin nums

  while(1)  // bb             primary loop
  {
// *** DS1620 data
    degC = get_1620(spia_1, IOPIN1620, CLKPIN1620, RESET1620);                                                  // Read DS1620 
    if(degC & 0b100000000) degC = degC | 0xFFFFFF00; // degC <0, convert to 32bit signed int
    degC *= 5;                            // data is in 1/2 degree increments, make degC = 10 x
    degF = degC * 9 / 5 + 320;
    fdegC = degC;
    fdegF = degF;
    print(" %.1f deg C   ", fdegC/10);
    print(" %.1f deg F\n", fdegF/10);
    pause(800);
  }            // end bb      end primary loop
}              // end main

// *** Functions are in libspiasm ***
