/* demo mma7455-spi lib functions.c       Accelerometer interface using spiasm library
   main() is demo of MMA7455 functions:
                                        void start_MMA7455()
                                        signed char get_MMA7455(int axis) 
************* This version has functions in libspiasm *************
 
  Based on C-Learning SPI tutorial by Andy Lindsay
   
  Uses pasm in xspiasm.spin, modified from SPI_Asm.spin propeller tool library object.
   T Montemarano  (MIT License)
   
   The SPI device called in main() is a MMA7455 Accelerometer.    
*/
 
#include "simpletools.h"                      // Library includes
#include "spiasm.h"
   
/* ******************************************************
    Uses MMA7455 Accelerometer as SPI device
 
     MMA7455 pin              Prop pin 

          CS            <-    Prop P6  low starts transfer, high terminates
          DATA in/out   <->   Prop P7. Prop out (MFIRST), Prop in (MPRE)
          Clock         <-    Prop P8  rise then fall  State = 0
*/
 
#define cstate_7455 0            // put in function 0 = start clock low, 1 = start clock high
#define clockd_ns7455 1000   // Actual delay in nanoseconds (1000ns = 1 usec), not less than 300ns
                             // ClockDelay, actual clock delay = 300ns + (cdelay-1) * 50ns
                             // e.g. cdelay of 15 gives actual clock delay = 1 usec
                             // cdelay = ((clockd_ns) - 250ns)) / 50ns
                             // e.g. for 2 usec (i.e. 2000 ns): cdelay = 35
//  ** Propeller pins 
#define CS7455 6
#define IOPIN7455 7
#define CLKPIN7455 8

// *** Function prototypes  shouldn't need since they are in spiasm.h
//spia_t *start_MMA7455(int, int);      // clockd_ns7455, cstate_7455
//void init_MMA7455(spia_t *device, int, int, int);    // IOPIN7455, CLKPIN7455, CS7455 - initialize and configure DS1620
//signed char get_MMA7455(spia_t *device, int, int, int, int); // IOPIN7455, CLKPIN7455, CS7455, axis -- read accel

spia_t *spia_1; // for opening additional SPI cogs add *spia_2, etc. Note multiple SPI devices can share same cog.

#define RXOUT 0x06    // MMA7455 Command to Read xOUT register  0x06 (bit 7 is READ)
#define RYOUT 0x07
#define RZOUT 0x08 
   
int main()                                    // Main function
{ 
  signed char accvalue[4]; 
  int i;
  spia_1 = start_MMA7455(clockd_ns7455, cstate_7455);
  init_MMA7455(spia_1, IOPIN7455, CLKPIN7455, CS7455);
  while(1)  
  {
    for(i = RXOUT; i <= RZOUT; i++)     // i is axis
    {
      accvalue[i-5] = get_MMA7455(spia_1, IOPIN7455, CLKPIN7455, CS7455, i);
    }
  printi(" %c x = %d%c\n", HOME, accvalue[1], CLREOL);
  printi("  y = %d%c\n",  accvalue[2], CLREOL);
  printi("  z = %d%c\n",  accvalue[3], CLREOL);
  pause(500);
  }    // end while
}      // end main

// **** Functions ****
//  Functions are now in libspiasm
